@@ -1,4 +1,4 @@
-"""mssdk 是基于 Python 的为麦思多维科技客户服务的专用 API 接口"""
+"""MSSDK 是基于 Python 的为麦思多维科技客户服务的专用 API 接口"""
 
 """
 0.0.1: 发布测试版本 v0.0.1
@@ -8,11 +8,240 @@
 0.0.5: 发布测试版本 v0.0.5
 0.0.6: 发布测试版本 v0.0.6
 0.0.7: 发布测试版本 v0.0.7
+0.0.8: 发布测试版本 v0.0.8
+0.0.9: 发布测试版本 v0.0.9
 """
 
-__version__ = '0.0.7'
+__version__ = '0.0.9'
 __author__ = 'mssdk'
 
+import sys
+
+if sys.version_info < (3, 7):
+    print(f"AkShare {__version__} requires Python 3.7+")
+    sys.exit(1)
+
+del sys
+
+"""
+银行-全球银行排名
+"""
+from mssdk.bank.bank_banker import bank_rank_banker
+
+"""
+债券概览
+"""
+from mssdk.bond.bond_summary import bond_deal_summary_sse
+
+"""
+新闻-个股新闻
+"""
+from mssdk.news.stock_news import stock_news_em
+
+"""
+股票数据-一致行动人
+"""
+from mssdk.stock_feature.stock_em_yzxdr import stock_em_yzxdr
+
+"""
+大宗交易
+"""
+from mssdk.stock.stock_dzjy import stock_dzjy_sctj, stock_dzjy_mrmx, stock_dzjy_mrtj, stock_dzjy_hygtj, stock_dzjy_yybph, stock_dzjy_hyyybtj
+
+"""
+国证指数
+"""
+from mssdk.index.index_cni import index_cni_hist, index_cni_all, index_cni_detail, index_cni_detail_hist, index_cni_detail_hist_adjust
+
+"""
+金十数据-新闻资讯
+"""
+from mssdk.ws.js_ws_news import js_news
+
+"""
+东方财富-期权
+"""
+from mssdk.option.option_em import option_current_em
+
+"""
+科创板报告
+"""
+from mssdk.stock.zh_stock_kcb_report import zh_stock_kcb_report
+
+"""
+期货合约详情
+"""
+from mssdk.futures.futures_contract_detail import futures_contract_detail
+
+"""
+胡润排行榜
+"""
+from mssdk.fortune.hurun import hurun_rank
+
+"""
+新财富富豪榜
+"""
+from mssdk.fortune.xincaifu_500 import xincaifu_rank
+
+"""
+福布斯中国榜单
+"""
+from mssdk.fortune.forbes_500 import forbes_rank
+
+"""
+回购定盘利率
+"""
+from mssdk.rate.repo_rate import repo_rate_hist
+
+"""
+公募基金排行
+"""
+from mssdk.fund.fund_em_rank import (
+    fund_em_exchange_rank,
+    fund_em_money_rank,
+    fund_em_open_fund_rank,
+    fund_em_hk_rank,
+    fund_em_lcx_rank,
+)
+
+"""
+英为财情-加密货币
+"""
+from mssdk.crypto.crypto_hist_investing import crypto_hist, crypto_name_map
+
+"""
+电影票房
+"""
+from mssdk.movie.movie_yien import (
+    movie_boxoffice_cinema_daily,
+    movie_boxoffice_cinema_weekly,
+    movie_boxoffice_weekly,
+    movie_boxoffice_daily,
+    movie_boxoffice_monthly,
+    movie_boxoffice_realtime,
+    movie_boxoffice_yearly,
+    movie_boxoffice_yearly_first_week,
+)
+
+"""
+新闻联播文字稿
+"""
+from mssdk.news.cctv_news import news_cctv
+
+"""
+债券收盘收益率曲线历史数据
+"""
+from mssdk.bond.bond_china_money import (
+    bond_china_close_return,
+    bond_china_close_return_map,
+)
+
+"""
+COMEX黄金-白银库存
+"""
+from mssdk.futures.futures_comex import futures_comex_inventory
+
+"""
+国债期货可交割券相关指标
+"""
+from mssdk.bond.bond_futures import bond_futures_deliverable_coupons
+
+"""
+A 股-次新股
+"""
+from mssdk.stock.stock_zh_a_new import stock_zh_a_new
+
+"""
+东方财富-注册制审核
+"""
+from mssdk.stock_fundamental.stock_register import (
+    stock_register_kcb,
+    stock_register_cyb,
+)
+
+"""
+新浪财经-龙虎榜
+"""
+from mssdk.stock_feature.stock_sina_lhb import (
+    stock_sina_lhb_detail_daily,
+    stock_sina_lhb_ggtj,
+    stock_sina_lhb_jgmx,
+    stock_sina_lhb_jgzz,
+    stock_sina_lhb_yytj,
+)
+
+"""
+中证指数
+"""
+from mssdk.index.zh_stock_index_csindex import stock_zh_index_hist_csindex
+
+"""
+股票基金持仓数据
+"""
+from mssdk.stock.stock_fund_hold import stock_report_fund_hold
+
+"""
+期货分钟数据
+"""
+from mssdk.futures.futures_zh_sina import futures_zh_minute_sina
+
+"""
+股票财务报告预约披露
+"""
+from mssdk.stock_feature.stock_cninfo_yjyg import stock_report_disclosure
+
+"""
+基金行情
+"""
+from mssdk.fund.fund_etf import fund_etf_hist_sina, fund_etf_category_sina
+
+"""
+交易日历
+"""
+from mssdk.tool.trade_date_hist import tool_trade_date_hist_sina
+
+"""
+commodity option
+"""
+from mssdk.option.option_commodity_sina import (
+    option_sina_commodity_contract_list,
+    option_sina_commodity_dict,
+    option_sina_commodity_hist,
+)
+
+"""
+A 股PE和PB
+"""
+from mssdk.stock_feature.stock_a_pb import stock_a_pb
+from mssdk.stock_feature.stock_a_pe import stock_a_pe
+from mssdk.stock_feature.stock_a_indicator import (
+    stock_a_lg_indicator,
+    stock_hk_eniu_indicator,
+)
+from mssdk.stock_feature.stock_a_high_low import stock_a_high_low_statistics
+from mssdk.stock_feature.stock_a_below_net_asset_statistics import (
+    stock_a_below_net_asset_statistics,
+)
+
+"""
+彭博亿万富豪指数
+"""
+from mssdk.fortune.fortune_bloomberg import index_bloomberg_billionaires
+
+"""
+stock-券商业绩月报
+"""
+from mssdk.stock_feature.stock_em_qsjy import stock_em_qsjy
+
+"""
+futures-warehouse-receipt
+"""
+from mssdk.futures.futures_warehouse_receipt import (
+    futures_czce_warehouse_receipt,
+    futures_dce_warehouse_receipt,
+    futures_shfe_warehouse_receipt,
+)
+
 """
 stock-js
 """
@@ -26,12 +255,18 @@ from mssdk.stock.stock_summary import stock_sse_summary, stock_szse_summary
 """
 股票-机构推荐池
 """
-from mssdk.stock_fundamental.stock_recommend import stock_institute_recommend, stock_institute_recommend_detail
+from mssdk.stock_fundamental.stock_recommend import (
+    stock_institute_recommend,
+    stock_institute_recommend_detail,
+)
 
 """
 股票-机构持股
 """
-from mssdk.stock_fundamental.stock_hold import stock_institute_hold_detail, stock_institute_hold
+from mssdk.stock_fundamental.stock_hold import (
+    stock_institute_hold_detail,
+    stock_institute_hold,
+)
 
 """
 stock-info
@@ -100,7 +335,7 @@ from mssdk.stock_feature.stock_em_yjyg import stock_em_yjyg, stock_em_yysj
 """
 stock
 """
-from mssdk.stock_feature.stock_em_dxsyl import stock_em_dxsyl
+from mssdk.stock_feature.stock_em_dxsyl import stock_em_dxsyl, stock_em_xgsglb
 
 """
 article
@@ -166,6 +401,10 @@ from mssdk.stock_feature.stock_em_hsgt import (
     stock_em_hsgt_south_cash,
     stock_em_hsgt_south_net_flow_in,
     stock_em_hsgt_hold_stock,
+    stock_em_hsgt_hist,
+    stock_em_hsgt_institution_statistics,
+    stock_em_hsgt_stock_statistics,
+    stock_em_hsgt_board_rank,
 )
 
 """
@@ -205,7 +444,7 @@ from mssdk.currency.currency import (
 """
 知识图谱
 """
-from mssdk.nlp.nlp_interface import nlp_ownthink
+from mssdk.nlp.nlp_interface import nlp_ownthink, nlp_answer
 
 """
 微博舆情报告
@@ -227,6 +466,7 @@ from mssdk.option.option_finance_sina import (
     option_sina_sse_greeks,
     option_sina_sse_minute,
     option_sina_sse_daily,
+    option_sina_finance_minute,
 )
 
 """
@@ -250,7 +490,13 @@ from mssdk.event.franchise import franchise_china
 债券-沪深债券
 """
 from mssdk.bond.zh_bond_sina import bond_zh_hs_daily, bond_zh_hs_spot
-from mssdk.bond.zh_bond_cov_sina import bond_zh_hs_cov_daily, bond_zh_hs_cov_spot, bond_cov_comparison, bond_zh_cov
+from mssdk.bond.zh_bond_cov_sina import (
+    bond_zh_hs_cov_daily,
+    bond_zh_hs_cov_spot,
+    bond_cov_comparison,
+    bond_zh_cov,
+)
+from mssdk.bond.bond_convert import bond_cov_jsl
 
 """
 for pro api
@@ -271,9 +517,6 @@ from mssdk.bond.china_repo import bond_repo_zh_tick
 新型肺炎
 """
 from mssdk.event.covid import (
-    covid_19_area_search,
-    covid_19_area_all,
-    covid_19_area_detail,
     covid_19_trip,
     covid_19_history,
 )
@@ -322,6 +565,7 @@ from mssdk.event.covid import (
 from mssdk.fx.currency_investing import (
     currency_hist,
     currency_name_code,
+    currency_pair_map,
 )
 
 """
@@ -364,7 +608,6 @@ from mssdk.economic.macro_euro import (
     macro_euro_zew_economic_sentiment,
     macro_euro_lme_holding,
     macro_euro_lme_stock,
-
 )
 
 """
@@ -479,6 +722,10 @@ from mssdk.index.index_yw import index_yw
 from mssdk.index.index_cons import (
     index_stock_info,
     index_stock_cons,
+    index_stock_hist,
+    index_stock_cons_sina,
+    index_stock_cons_csindex,
+    stock_a_code_to_symbol
 )
 
 """
@@ -528,7 +775,7 @@ from mssdk.stock_feature.stock_em_gpzy import (
 from mssdk.stock_feature.stock_em_jgdy import stock_em_jgdy_tj, stock_em_jgdy_detail
 
 """
-新浪主力连续接口
+IT桔子
 """
 from mssdk.fortune.it_juzi import death_company, maxima_company, nicorn_company
 
@@ -556,14 +803,15 @@ from mssdk.index.index_spot import spot_goods
 from mssdk.cost.cost_living import cost_living
 
 """
-能约-碳排放权
+能源-碳排放权
 """
-from mssdk.energy.energy_carbon import energy_carbon
-
-"""
-猫眼电影实时票房
-"""
-from mssdk.movie.movie_maoyan import box_office_spot
+from mssdk.energy.energy_carbon import (
+    energy_carbon_bj,
+    energy_carbon_eu,
+    energy_carbon_gz,
+    energy_carbon_hb,
+    energy_carbon_sz,
+)
 
 """
 中国证券投资基金业协会-信息公示
@@ -581,11 +829,7 @@ from mssdk.fund.fund_amac import (
     amac_securities_info,
     amac_fund_abs,
     amac_manager_classify_info,
-    amac_manager_xxgs_cxdj,
-    amac_manager_xxgs_hmd,
-    amac_manager_xxgs_jlcf,
     amac_person_org_list,
-    amac_person_org_list_ext,
 )
 
 """
@@ -668,6 +912,11 @@ from mssdk.futures_derivative.nh_index_volatility import nh_volatility_index
 """
 from mssdk.air.air_hebei import air_quality_hebei
 
+"""
+timeanddate-日出和日落
+"""
+from mssdk.air.time_and_date import sunrise_daily, sunrise_monthly
+
 """
 金十财经-实时监控
 """
@@ -690,6 +939,7 @@ from mssdk.index.zh_stock_index_sina import (
     stock_zh_index_daily,
     stock_zh_index_spot,
     stock_zh_index_daily_tx,
+    stock_zh_index_daily_em,
 )
 
 """
@@ -727,7 +977,12 @@ from mssdk.stock.zh_stock_kcb_sina import stock_zh_kcb_spot, stock_zh_kcb_daily
 """
 A股
 """
-from mssdk.stock.zh_stock_a_sina import stock_zh_a_spot, stock_zh_a_daily
+from mssdk.stock.zh_stock_a_sina import (
+    stock_zh_a_spot,
+    stock_zh_a_daily,
+    stock_zh_a_minute,
+    stock_zh_a_cdr_daily,
+)
 
 """
 A+H股
@@ -739,9 +994,9 @@ from mssdk.stock.zh_stock_ah_tx import (
 )
 
 """
-数字货币
+加密货币
 """
-from mssdk.economic.macro_other import get_js_dc_current
+from mssdk.economic.macro_other import crypto_js_spot
 
 """
 金融期权
@@ -754,7 +1009,12 @@ from mssdk.option.option_finance import (
 """
 新浪-美股实时行情数据和历史行情数据(前复权)
 """
-from mssdk.stock.us_stock_sina import stock_us_daily, stock_us_spot, get_us_stock_name
+from mssdk.stock.us_stock_sina import (
+    stock_us_daily,
+    stock_us_spot,
+    get_us_stock_name,
+    stock_us_fundamental,
+)
 
 """
 新浪-港股实时行情数据和历史数据(前复权和后复权因子)
@@ -764,7 +1024,7 @@ from mssdk.stock.hk_stock_sina import stock_hk_daily, stock_hk_spot
 """
 新浪-期货实时数据
 """
-from mssdk.futures.zh_futures_sina import futures_zh_spot, match_main_contract
+from mssdk.futures.futures_zh_sina import futures_zh_spot, match_main_contract
 
 """
 西本新干线-指数数据
@@ -811,7 +1071,6 @@ from mssdk.economic.macro_constitute import (
     macro_cons_gold_change,
     macro_cons_gold_volume,
     macro_cons_opec_month,
-    macro_cons_opec_near_change,
     macro_cons_silver_amount,
     macro_cons_silver_change,
     macro_cons_silver_volume,
@@ -898,10 +1157,41 @@ from mssdk.economic.macro_china import (
     macro_china_shibor_all,
     macro_china_industrial_production_yoy,
     macro_china_lpr,
-    macro_china_money_supply,
     macro_china_new_house_price,
     macro_china_enterprise_boom_index,
     macro_china_national_tax_receipts,
+    macro_china_new_financial_credit,
+    macro_china_fx_gold,
+    macro_china_money_supply,
+    macro_china_stock_market_cap,
+    macro_china_cpi,
+    macro_china_gdp,
+    macro_china_ppi,
+    macro_china_pmi,
+    macro_china_gdzctz,
+    macro_china_hgjck,
+    macro_china_czsr,
+    macro_china_whxd,
+    macro_china_wbck,
+    macro_china_bond_public,
+    macro_china_gksccz,
+    macro_china_hb,
+    macro_china_xfzxx,
+    macro_china_reserve_requirement_ratio,
+    macro_china_consumer_goods_retail,
+    macro_china_society_electricity,
+    macro_china_society_traffic_volume,
+    macro_china_postal_telecommunicational,
+    macro_china_international_tourism_fx,
+    macro_china_passenger_load_factor,
+    macro_china_freight_index,
+    macro_china_central_bank_balance,
+    macro_china_insurance,
+    macro_china_supply_of_money,
+    macro_china_swap_rate,
+    macro_china_foreign_exchange_gold,
+    macro_china_retail_price_index,
+    macro_china_real_estate,
 )
 
 """
@@ -934,28 +1224,29 @@ from mssdk.option.option_commodity import (
 """
 英为财情-债券
 """
-from mssdk.bond.bond_investing import bond_investing_global, bond_investing_global_country_name_url
+from mssdk.bond.bond_investing import (
+    bond_investing_global,
+    bond_investing_global_country_name_url,
+)
 
 """
 英为财情-指数
 """
-from mssdk.index.index_investing import index_investing_global, index_investing_global_country_name_url
+from mssdk.index.index_investing import (
+    index_investing_global,
+    index_investing_global_country_name_url,
+)
 
 """
 99期货-期货库存数据
 """
-from mssdk.futures.futures_inventory import get_inventory_data
+from mssdk.futures.futures_inventory import futures_inventory_99
 
 """
 东方财富-期货库存数据
 """
 from mssdk.futures.futures_inventory_em import futures_inventory_em
 
-"""
-私募指数
-"""
-from mssdk.fund.fund_zdzk import zdzk_fund_index
-
 """
 中国银行间市场交易商协会
 """
@@ -987,7 +1278,7 @@ from mssdk.qhkc_web.qhkc_fund import (
 """
 大宗商品现货价格及基差
 """
-from mssdk.futures.futures_basis import futures_spot_price_daily, futures_spot_price
+from mssdk.futures.futures_basis import futures_spot_price_daily, futures_spot_price, futures_spot_price_previous
 
 """
 期货持仓成交排名数据
@@ -1011,12 +1302,12 @@ from mssdk.futures.receipt import get_receipt
 """
 大宗商品展期收益率数据
 """
-from mssdk.futures.roll_yield import get_roll_yield_bar, get_roll_yield
+from mssdk.futures.futures_roll_yield import get_roll_yield_bar, get_roll_yield
 
 """
 交易所日线行情数据
 """
-from mssdk.futures.daily_bar import (
+from mssdk.futures.futures_daily_bar import (
     get_cffex_daily,
     get_czce_daily,
     get_shfe_v_wap,
@@ -1024,14 +1315,3 @@ from mssdk.futures.daily_bar import (
     get_dce_daily,
     get_futures_daily,
 )
-
-"""
-配置文件
-"""
-from mssdk.futures import cons
-from mssdk.fund import cons
-
-"""
-发邮件模块
-"""
-from mssdk.tool.send_email import send_email
