@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Date: 2020/4/27 21:13
+Date: 2020/10/19 9:13
 Desc: 真气网-空气质量
 https://www.zq12369.com/environment.php
 空气质量在线监测分析平台的空气质量数据
@@ -12,7 +12,7 @@ import os
 import re
 
 import demjson
-import execjs
+from py_mini_racer import py_mini_racer
 import pandas as pd
 import requests
 
@@ -72,11 +72,10 @@ def air_city_list() -> list:
     return pd.read_html(r.text)[1].iloc[1:, :]["城市"].tolist()
 
 
-def air_quality_watch_point(
-    city: str = "杭州", start_date: str = "2018-01-01", end_date: str = "2020-04-27"
-) -> pd.DataFrame:
+def air_quality_watch_point(city: str = "杭州", start_date: str = "2018-01-01", end_date: str = "2020-04-27") -> pd.DataFrame:
     """
     真气网-监测点空气质量-细化到具体城市的每个监测点
+    指定之间段之间的空气质量数据
     https://www.zq12369.com/
     :param city: 调用 air_city_list 接口获取
     :type city: str
@@ -87,9 +86,11 @@ def air_quality_watch_point(
     :return: 指定城市指定日期区间的观测点空气质量
     :rtype: pandas.DataFrame
     """
+
     url = "https://www.zq12369.com/api/zhenqiapi.php"
     file_data = _get_file_content(file_name="crypto.js")
-    ctx = execjs.compile(file_data)
+    ctx = py_mini_racer.MiniRacer()
+    ctx.eval(file_data)
     method = "GETCITYPOINTAVG"
     ctx.call("encode_param", method)
     ctx.call("encode_param", start_date)
@@ -115,10 +116,7 @@ def air_quality_watch_point(
 
 
 def air_quality_hist(
-    city: str = "杭州",
-    period: str = "day",
-    start_date: str = "2019-03-27",
-    end_date: str = "2020-04-27",
+    city: str = "杭州", period: str = "day", start_date: str = "2019-03-27", end_date: str = "2020-04-27"
 ) -> pd.DataFrame:
     """
     真气网-空气历史数据
@@ -136,10 +134,11 @@ def air_quality_hist(
     """
     url = "https://www.zq12369.com/api/newzhenqiapi.php"
     file_data = _get_file_content(file_name="outcrypto.js")
-    out = execjs.compile(file_data)
+    ctx = py_mini_racer.MiniRacer()
+    ctx.eval(file_data)
     appId = "4f0e3a273d547ce6b7147bfa7ceb4b6e"
     method = "CETCITYPERIOD"
-    timestamp = execjs.eval("timestamp = new Date().getTime()")
+    timestamp = ctx.eval("timestamp = new Date().getTime()")
     p_text = json.dumps(
         {
             "city": city,
@@ -150,7 +149,7 @@ def air_quality_hist(
         ensure_ascii=False,
         indent=None,
     ).replace(' "', '"')
-    secret = out.call("hex_md5", appId + method + str(timestamp) + "WEB" + p_text)
+    secret = ctx.call("hex_md5", appId + method + str(timestamp) + "WEB" + p_text)
     payload = {
         "appId": "4f0e3a273d547ce6b7147bfa7ceb4b6e",
         "method": "CETCITYPERIOD",
@@ -175,10 +174,10 @@ def air_quality_hist(
     headers = {
         "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.122 Safari/537.36"
     }
-    params = {"param": out.call("AES.encrypt", need)}
+    params = {"param": ctx.call("AES.encrypt", need)}
     r = requests.post(url, data=params, headers=headers)
-    temp_text = out.call("decryptData", r.text)
-    data_json = demjson.decode(out.call("b.decode", temp_text))
+    temp_text = ctx.call("decryptData", r.text)
+    data_json = demjson.decode(ctx.call("b.decode", temp_text))
     temp_df = pd.DataFrame(data_json["result"]["data"]["rows"])
     temp_df.index = temp_df["time"]
     del temp_df["time"]
@@ -186,51 +185,6 @@ def air_quality_hist(
     return temp_df
 
 
-# def _air_quality_rank(city="杭州", period="day", start_date="2019-03-27", end_date="2020-04-27"):
-#     url = "https://www.zq12369.com/api/newzhenqiapi.php"
-#     with open(r"mssdk/air_new/outcrypto.js") as file:
-#         file_data = file.read()
-#     out = execjs.compile(file_data)
-#     appId = "4f0e3a273d547ce6b7147bfa7ceb4b6e"
-#     method = "GETCITYAQIRANK"
-#     timestamp = execjs.eval("timestamp = new Date().getTime()")
-#     p_text = json.dumps(
-#         {
-#             "order": "desc",
-#         },
-#         ensure_ascii=False,
-#         indent=None,
-#     ).replace(' "', '"')
-#     secret = out.call("hex_md5", appId + method + str(timestamp) + "WEB" + p_text)
-#     payload = {
-#         "appId": "4f0e3a273d547ce6b7147bfa7ceb4b6e",
-#         "method": method,
-#         "timestamp": int(timestamp),
-#         "clienttype": "WEB",
-#         "object": {
-#             "order": "desc",
-#         },
-#         "secret": secret,
-#     }
-#     need = (
-#         json.dumps(payload, ensure_ascii=False, indent=None, sort_keys=False)
-#         .replace(' "', '"')
-#         .replace("\\", "")
-#         .replace('p": ', 'p":')
-#         .replace('t": ', 't":')
-#     )
-#
-#     headers = {
-#         "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.122 Safari/537.36"
-#     }
-#     params = {"param": out.call("AES.encrypt", need)}
-#     r = requests.post(url, data=params, headers=headers)
-#     temp_text = out.call("decryptData", r.text)
-#     data_json = demjson.decode(out.call("b.decode", temp_text))
-#     temp_df = pd.DataFrame(data_json["result"]["data"]["rows"])
-#     return temp_df
-
-
 def air_quality_rank(date: str = "2020-03-12") -> pd.DataFrame:
     """
     真气网-168城市AQI排行榜
@@ -284,12 +238,12 @@ if __name__ == "__main__":
     print(air_city_list_map)
 
     air_quality_watch_point_df = air_quality_watch_point(
-        city="杭州", start_date="2020-01-01", end_date="2020-05-13"
+        city="杭州", start_date="2020-11-01", end_date="2020-11-07"
     )
     print(air_quality_watch_point_df)
 
     air_quality_hist_df = air_quality_hist(
-        city="北京", period="day", start_date="2020-04-25", end_date="2020-05-01"
+        city="北京", period="day", start_date="2020-04-25", end_date="2020-07-04"
     )
     print(air_quality_hist_df)
 
