@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Date: 2020/4/10 19:46
+Date: 2020/12/28 16:01
 Desc: 美国股市(S&P 500)的指数及其收益率，还有常用的14个经济指标
 http://www.hec.unil.ch/agoyal/
 http://www.hec.unil.ch/agoyal/docs/PredictorData2018.xlsx
@@ -19,11 +19,11 @@ def agoyal_stock_return(indicator: str = "monthly"):
     """
     url = "http://www.hec.unil.ch/agoyal/docs/PredictorData2018.xlsx"
     if indicator == "monthly":
-        return pd.read_excel(url, sheet_name="Monthly")
+        return pd.read_excel(url, sheet_name="Monthly", engine="openpyxl")
     if indicator == "quarterly":
-        return pd.read_excel(url, sheet_name="Quarterly")
+        return pd.read_excel(url, sheet_name="Quarterly", engine="openpyxl")
     if indicator == "annual":
-        return pd.read_excel(url, sheet_name="Annual")
+        return pd.read_excel(url, sheet_name="Annual", engine="openpyxl")
 
 
 if __name__ == '__main__':
