@@ -1,10 +1,8 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Author: Albert King
-date: 2020/2/9 11:48
-contact: jindaxiang@163.com
-desc: 腾讯-债券-质押式回购-实时行情-成交明细
+Date: 2020/10/29 11:48
+Desc: 腾讯-债券-质押式回购-实时行情-成交明细
 下载成交明细-每个交易日16:00提供当日数据
 http://stockhtm.finance.qq.com/sstock/ggcx/131802.shtml
 """
@@ -14,9 +12,10 @@ import pandas as pd
 import requests
 
 
-def bond_repo_zh_tick(code="sz131802", trade_date="20200207"):
+def bond_repo_zh_tick(code="sz131802", trade_date="20201028"):
     """
     成交明细-每个交易日16:00提供当日数据
+    http://stockhtm.finance.qq.com/sstock/ggcx/131802.shtml
     :param code: 带市场标识的债券-质押式回购代码
     :type code: str
     :param trade_date: 需要提取数据的日期
@@ -31,14 +30,14 @@ def bond_repo_zh_tick(code="sz131802", trade_date="20200207"):
         "c": code,
         "d": trade_date,
     }
-    res = requests.get(url, params=params)
-    res.encoding = "gbk"
-    temp_df = pd.read_table(StringIO(res.text))
+    r = requests.get(url, params=params)
+    r.encoding = "gbk"
+    temp_df = pd.read_table(StringIO(r.text))
     return temp_df
 
 
 if __name__ == "__main__":
-    date_list = pd.date_range(start="20190801", end="20200209").tolist()
+    date_list = pd.date_range(start="20201001", end="20201028").tolist()
     date_list = [item.strftime("%Y%m%d") for item in date_list]
     for item in date_list:
         data = bond_repo_zh_tick(code="sz131802", trade_date=f"{item}")
